from typing import Sequence

from fast_depends.types import AnyDict, P


def args_to_kwargs(
    arguments: Sequence[str], *args: P.args, **kwargs: P.kwargs
) -> AnyDict:
    if not args:
        return kwargs

    unused = filter(lambda x: x not in kwargs, arguments)

    return dict((*zip(unused, args), *kwargs.items()))



from typing import Any, Callable, Dict, TypeVar
from typing_extensions import ParamSpec, TypeAlias

P = ParamSpec("P")

AnyCallable = TypeVar("AnyCallable", bound=Callable[..., Any])
DecoratedCallable: TypeAlias = AnyCallable
AnyDict = TypeVar("AnyDict", bound=Dict[str, Any])
